==> huaweicloudsdkief-3.1.107-py2.py3-none-any.whl: huaweicloudsdkief/v1/model/update_app_version_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateAppVersionRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'ief_instance_id': 'str',
        'app_id': 'str',
        'version_id': 'str',
        'body': 'UpdataAppVersionBody'
    }

    attribute_map = {
        'ief_instance_id': 'ief-instance-id',
        'app_id': 'app_id',
        'version_id': 'version_id',
        'body': 'body'
    }

    def __init__(self, ief_instance_id=None, app_id=None, version_id=None, body=None):
        """UpdateAppVersionRequest

        The model defined in huaweicloud sdk

        :param ief_instance_id: 铂金版实例ID，专业版实例为空值
        :type ief_instance_id: str
        :param app_id: 应用模板ID
        :type app_id: str
        :param version_id: 应用模板版本ID
        :type version_id: str
        :param body: Body of the UpdateAppVersionRequest
        :type body: :class:`huaweicloudsdkief.v1.UpdataAppVersionBody`
        """
        
        

        self._ief_instance_id = None
        self._app_id = None
        self._version_id = None
        self._body = None
        self.discriminator = None

        if ief_instance_id is not None:
            self.ief_instance_id = ief_instance_id
        self.app_id = app_id
        self.version_id = version_id
        if body is not None:
            self.body = body

    @property
    def ief_instance_id(self):
        """Gets the ief_instance_id of this UpdateAppVersionRequest.

        铂金版实例ID，专业版实例为空值

        :return: The ief_instance_id of this UpdateAppVersionRequest.
        :rtype: str
        """
        return self._ief_instance_id

    @ief_instance_id.setter
    def ief_instance_id(self, ief_instance_id):
        """Sets the ief_instance_id of this UpdateAppVersionRequest.

        铂金版实例ID，专业版实例为空值

        :param ief_instance_id: The ief_instance_id of this UpdateAppVersionRequest.
        :type ief_instance_id: str
        """
        self._ief_instance_id = ief_instance_id

    @property
    def app_id(self):
        """Gets the app_id of this UpdateAppVersionRequest.

        应用模板ID

        :return: The app_id of this UpdateAppVersionRequest.
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this UpdateAppVersionRequest.

        应用模板ID

        :param app_id: The app_id of this UpdateAppVersionRequest.
        :type app_id: str
        """
        self._app_id = app_id

    @property
    def version_id(self):
        """Gets the version_id of this UpdateAppVersionRequest.

        应用模板版本ID

        :return: The version_id of this UpdateAppVersionRequest.
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this UpdateAppVersionRequest.

        应用模板版本ID

        :param version_id: The version_id of this UpdateAppVersionRequest.
        :type version_id: str
        """
        self._version_id = version_id

    @property
    def body(self):
        """Gets the body of this UpdateAppVersionRequest.

        :return: The body of this UpdateAppVersionRequest.
        :rtype: :class:`huaweicloudsdkief.v1.UpdataAppVersionBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateAppVersionRequest.

        :param body: The body of this UpdateAppVersionRequest.
        :type body: :class:`huaweicloudsdkief.v1.UpdataAppVersionBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAppVersionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkief-3.1.157-py2.py3-none-any.whl: huaweicloudsdkief/v1/model/update_app_version_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateAppVersionRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'ief_instance_id': 'str',
        'app_id': 'str',
        'version_id': 'str',
        'body': 'UpdataAppVersionBody'
    }

    attribute_map = {
        'ief_instance_id': 'ief-instance-id',
        'app_id': 'app_id',
        'version_id': 'version_id',
        'body': 'body'
    }

    def __init__(self, ief_instance_id=None, app_id=None, version_id=None, body=None):
        r"""UpdateAppVersionRequest

        The model defined in huaweicloud sdk

        :param ief_instance_id: 铂金版实例ID，专业版实例为空值
        :type ief_instance_id: str
        :param app_id: 应用模板ID
        :type app_id: str
        :param version_id: 应用模板版本ID
        :type version_id: str
        :param body: Body of the UpdateAppVersionRequest
        :type body: :class:`huaweicloudsdkief.v1.UpdataAppVersionBody`
        """
        
        

        self._ief_instance_id = None
        self._app_id = None
        self._version_id = None
        self._body = None
        self.discriminator = None

        if ief_instance_id is not None:
            self.ief_instance_id = ief_instance_id
        self.app_id = app_id
        self.version_id = version_id
        if body is not None:
            self.body = body

    @property
    def ief_instance_id(self):
        r"""Gets the ief_instance_id of this UpdateAppVersionRequest.

        铂金版实例ID，专业版实例为空值

        :return: The ief_instance_id of this UpdateAppVersionRequest.
        :rtype: str
        """
        return self._ief_instance_id

    @ief_instance_id.setter
    def ief_instance_id(self, ief_instance_id):
        r"""Sets the ief_instance_id of this UpdateAppVersionRequest.

        铂金版实例ID，专业版实例为空值

        :param ief_instance_id: The ief_instance_id of this UpdateAppVersionRequest.
        :type ief_instance_id: str
        """
        self._ief_instance_id = ief_instance_id

    @property
    def app_id(self):
        r"""Gets the app_id of this UpdateAppVersionRequest.

        应用模板ID

        :return: The app_id of this UpdateAppVersionRequest.
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        r"""Sets the app_id of this UpdateAppVersionRequest.

        应用模板ID

        :param app_id: The app_id of this UpdateAppVersionRequest.
        :type app_id: str
        """
        self._app_id = app_id

    @property
    def version_id(self):
        r"""Gets the version_id of this UpdateAppVersionRequest.

        应用模板版本ID

        :return: The version_id of this UpdateAppVersionRequest.
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        r"""Sets the version_id of this UpdateAppVersionRequest.

        应用模板版本ID

        :param version_id: The version_id of this UpdateAppVersionRequest.
        :type version_id: str
        """
        self._version_id = version_id

    @property
    def body(self):
        r"""Gets the body of this UpdateAppVersionRequest.

        :return: The body of this UpdateAppVersionRequest.
        :rtype: :class:`huaweicloudsdkief.v1.UpdataAppVersionBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UpdateAppVersionRequest.

        :param body: The body of this UpdateAppVersionRequest.
        :type body: :class:`huaweicloudsdkief.v1.UpdataAppVersionBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAppVersionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
